@@ -346,7 +346,7 @@ def set_endpoint(endpoint_url, ssl=False, login=False,
     return True
 
 
-# pylint: disable=R0913
+# pylint: disable=R0913,R0902
 class DockerContainer:
     """
     Helper class for Docker container automation without using Ansible
@@ -382,6 +382,7 @@ class DockerContainer:
         return self.container
 
 
+# pylint: disable=W0703,R1718
 def start_docker_containers(docker_containers, network_name='demo'):
     """
     Deploys a list of DockerContainer's on a given network
@@ -470,7 +471,8 @@ def strip_snapshot(java_version):
     return re.sub("-SNAPSHOT", "", java_version)
 
 
-def check_version(base, comparator=None, service='nifi'):
+def check_version(base, comparator=None, service='nifi',
+                  default_version='0.2.0'):
     """
     Compares version base against either version comparator, or the version
     of the currently connected service instance.
@@ -482,6 +484,8 @@ def check_version(base, comparator=None, service='nifi'):
     Args:
         base (str): The base version for the comparison test
         comparator (optional[str]): The version to compare against
+        default_version (optional[str]): The version to assume the service is
+            if the check cannot be completed
         service (str): The service to test the version against, currently
             only supports NiFi
 
@@ -508,13 +512,11 @@ def check_version(base, comparator=None, service='nifi'):
             )
             reg_json = load(reg_swagger_def[0].data)
             ver_b = version.parse(reg_json['info']['version'])
-        except nipyapi.registry.rest.ApiException as e:
-            if e.status == 404:
-                log.warning("Unable to retrieve swagger.json from registry "
-                            "to check version, assuming older than 0.3")
-                ver_b = version.parse('0.2.0')
-            else:
-                raise
+        except nipyapi.registry.rest.ApiException:
+            log.warning(
+                "Unable to retrieve registry swagger.json, assuming version %s"
+                % default_version)
+            ver_b = version.parse(default_version)
     else:
         # Working with NiFi
         ver_b = version.parse(
@@ -530,11 +532,25 @@ def check_version(base, comparator=None, service='nifi'):
     return 0
 
 
-def validate_parameters_versioning_support():
-    """Convenience method to check if Parameters are supported"""
-    nifi_check = enforce_min_ver('1.10', bool_response=True)
-    registry_check = enforce_min_ver(
-        '0.6', service='registry', bool_response=True)
+def validate_parameters_versioning_support(verify_nifi=True,
+                                           verify_registry=True):
+    """
+    Convenience method to check if Parameters are supported
+    Args:
+        verify_nifi (bool): If True, check NiFi meets the min version
+        verify_registry (bool): If True, check Registry meets the min version
+    """
+    if verify_nifi:
+        nifi_check = enforce_min_ver('1.10', bool_response=True)
+    else:
+        nifi_check = False
+
+    if verify_registry:
+        registry_check = enforce_min_ver('0.6', service='registry',
+                                         bool_response=True)
+    else:
+        registry_check = False
+
     if nifi_check or registry_check:
         log.warning("Connected NiFi Registry may not support "
                     "Parameter Contexts and they may be lost in "
